@@ -47,9 +47,8 @@ class KafkaHelper:
                                  **self.sasl_config,
                                  **configs)
         try:
-            if not isinstance(value, bytes):
-                value = json.dumps(value)
-                value = value.encode("utf-8")
+            value = json.dumps(value).encode("utf-8")
+            key = json.dumps(key).encode("utf-8")
             future = producer.send(self.topic, value=value, key=key, headers=headers, partition=partition,
                                    timestamp_ms=timestamp_ms)
             record_metadata = future.get(timeout=10)
